import { Plugin, PluginServiceApi, Builder } from "@cloudbase/framework-core";
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginFunctionInputs {
    /**
     * 函数根目录
     * @default functions
     */
    functionRootPath?: string;
    /**
     * 函数配置数组
     */
    functions?: ICloudFunction[];
    /**
     *
     * 服务路径配置
     *
     * 如
     *
     * ```json
     * {
     *   "hello-world": "/helloworld"
     * }
     * ```
     */
    servicePaths?: Record<string, string>;
}
export interface IFunctionTriggerOptions {
    functionName: string;
    triggers?: ICloudFunctionTrigger[];
    triggerName?: string;
    envId: string;
}
export interface ICloudFunctionTrigger {
    name: string;
    type: string;
    config: string;
}
export interface ICloudFunction {
    /**
     * 云函数名称，即为函数部署后的名称
     */
    name: string;
    /**
     * 函数处理方法名称，名称格式支持“文件名称.函数名称”形式
     * @default index.main
     */
    handler?: string;
    /**
     * 函数超时时间（1 - 60S）
     */
    timeout?: number;
    /**
     * 包含环境变量的键值对
     */
    envVariables?: Record<string, string | number | boolean>;
    /**
     * 运行时环境配置，可选值： `Nodejs8.9, Nodejs10.15 Php7, Java8`
     * @default Nodejs10.15
     */
    runtime?: string;
    /**
     * VPC
     */
    vpc?: IFunctionVPC;
    /**
     * 是否云端安装依赖，目前仅支持 Node.js
     */
    installDependency?: boolean;
    isWaitInstall?: boolean;
}
export interface IFunctionVPC {
    /**
     * vpc 的id
     */
    vpcId: string;
    /**
     * 子网id
     */
    subnetId: string;
}
declare type ResolveInputs = IFrameworkPluginFunctionInputs & {
    functionRootPath: string;
    functions: ICloudFunction[];
    servicePaths: {};
};
declare class FunctionPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginFunctionInputs;
    protected resolvedInputs: ResolveInputs;
    protected buildOutput: any;
    protected functions: ICloudFunction[];
    protected functionRootPath: string;
    protected builder: FunctionBuilder;
    protected outputs: Record<string, any>;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginFunctionInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    compile(): Promise<{
        EntryPoint: {
            Label: string;
            EntryType: string;
            HttpEntryPath: string;
        }[];
        Resources: Record<string, any>;
    }>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
    functionConfigToSAM(functionConfig: any): {
        Type: string;
        Properties: {
            Handler: any;
            Description: string;
            Runtime: any;
            FunctionName: any;
            MemorySize: any;
            Timeout: any;
            Environment: any;
            VpcConfig: any;
            HttpPath: string;
            InstallDependency: any;
            CodeUri: any;
            Role: string;
        };
    };
    toConstantCase(name: string): string;
    uploadToCos(localPath: string, cloudPath: string): Promise<string>;
}
interface FunctionBuilderBuildOptions {
    name: string;
    localPath: string;
    zipfileName: string;
}
interface FunctionBuilderOptions {
    /**
     * 项目根目录的绝对路径
     */
    projectPath: string;
}
export declare class FunctionBuilder extends Builder {
    constructor(options: FunctionBuilderOptions);
    build(options: FunctionBuilderBuildOptions[]): Promise<{
        functions: {
            name: string;
            options: {};
            source: string;
            entry: string;
        }[];
    }>;
    zipDir(src: string, dest: string): Promise<unknown>;
}
export declare const plugin: typeof FunctionPlugin;
export {};
//# sourceMappingURL=index.d.ts.map